@@ -251,34 +251,23 @@ $result_trees{'kbd'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'example'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'example',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'example'
           },
           'line_nr' => {
@@ -290,8 +279,7 @@ $result_trees{'kbd'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -385,34 +373,23 @@ $result_trees{'kbd'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'format'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'format',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'format'
           },
           'line_nr' => {
@@ -424,8 +401,7 @@ $result_trees{'kbd'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -479,16 +455,10 @@ $result_trees{'kbd'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[0]{'pa
 $result_trees{'kbd'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'kbd'}{'contents'}[8]{'contents'}[1];
 $result_trees{'kbd'}{'contents'}[8]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'kbd'}{'contents'}[8]{'contents'}[1];
 $result_trees{'kbd'}{'contents'}[8]{'contents'}[1]{'parent'} = $result_trees{'kbd'}{'contents'}[8];
-$result_trees{'kbd'}{'contents'}[8]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'kbd'}{'contents'}[8]{'contents'}[2];
 $result_trees{'kbd'}{'contents'}[8]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbd'}{'contents'}[8]{'contents'}[2]{'args'}[0];
-$result_trees{'kbd'}{'contents'}[8]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbd'}{'contents'}[8]{'contents'}[2]{'args'}[0];
-$result_trees{'kbd'}{'contents'}[8]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'kbd'}{'contents'}[8]{'contents'}[2]{'args'}[0];
 $result_trees{'kbd'}{'contents'}[8]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'kbd'}{'contents'}[8]{'contents'}[2];
-$result_trees{'kbd'}{'contents'}[8]{'contents'}[2]{'extra'}{'command'} = $result_trees{'kbd'}{'contents'}[8];
-$result_trees{'kbd'}{'contents'}[8]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'kbd'}{'contents'}[8]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'kbd'}{'contents'}[8]{'contents'}[2]{'parent'} = $result_trees{'kbd'}{'contents'}[8];
 $result_trees{'kbd'}{'contents'}[8]{'extra'}{'end_command'} = $result_trees{'kbd'}{'contents'}[8]{'contents'}[2];
-$result_trees{'kbd'}{'contents'}[8]{'extra'}{'spaces_after_command'} = $result_trees{'kbd'}{'contents'}[8]{'contents'}[0];
 $result_trees{'kbd'}{'contents'}[8]{'parent'} = $result_trees{'kbd'};
 $result_trees{'kbd'}{'contents'}[9]{'parent'} = $result_trees{'kbd'};
 $result_trees{'kbd'}{'contents'}[10]{'contents'}[0]{'parent'} = $result_trees{'kbd'}{'contents'}[10];
@@ -504,16 +474,10 @@ $result_trees{'kbd'}{'contents'}[12]{'contents'}[1]{'contents'}[1]{'args'}[0]{'p
 $result_trees{'kbd'}{'contents'}[12]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'kbd'}{'contents'}[12]{'contents'}[1];
 $result_trees{'kbd'}{'contents'}[12]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'kbd'}{'contents'}[12]{'contents'}[1];
 $result_trees{'kbd'}{'contents'}[12]{'contents'}[1]{'parent'} = $result_trees{'kbd'}{'contents'}[12];
-$result_trees{'kbd'}{'contents'}[12]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'kbd'}{'contents'}[12]{'contents'}[2];
 $result_trees{'kbd'}{'contents'}[12]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbd'}{'contents'}[12]{'contents'}[2]{'args'}[0];
-$result_trees{'kbd'}{'contents'}[12]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbd'}{'contents'}[12]{'contents'}[2]{'args'}[0];
-$result_trees{'kbd'}{'contents'}[12]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'kbd'}{'contents'}[12]{'contents'}[2]{'args'}[0];
 $result_trees{'kbd'}{'contents'}[12]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'kbd'}{'contents'}[12]{'contents'}[2];
-$result_trees{'kbd'}{'contents'}[12]{'contents'}[2]{'extra'}{'command'} = $result_trees{'kbd'}{'contents'}[12];
-$result_trees{'kbd'}{'contents'}[12]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'kbd'}{'contents'}[12]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'kbd'}{'contents'}[12]{'contents'}[2]{'parent'} = $result_trees{'kbd'}{'contents'}[12];
 $result_trees{'kbd'}{'contents'}[12]{'extra'}{'end_command'} = $result_trees{'kbd'}{'contents'}[12]{'contents'}[2];
-$result_trees{'kbd'}{'contents'}[12]{'extra'}{'spaces_after_command'} = $result_trees{'kbd'}{'contents'}[12]{'contents'}[0];
 $result_trees{'kbd'}{'contents'}[12]{'parent'} = $result_trees{'kbd'};
 
 $result_texis{'kbd'} = 'kbd: @code{in kbd}.
