@@ -16,27 +16,17 @@ $result_trees{'image_and_punctuation'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -69,11 +59,7 @@ $result_trees{'image_and_punctuation'} = {
               'cmdname' => 'image',
               'contents' => [],
               'extra' => {
-                'brace_command_contents' => [
-                  [
-                    {}
-                  ]
-                ]
+                'input_perl_encoding' => 'utf-8'
               },
               'line_nr' => {
                 'file_name' => '',
@@ -119,11 +105,7 @@ $result_trees{'image_and_punctuation'} = {
               'cmdname' => 'image',
               'contents' => [],
               'extra' => {
-                'brace_command_contents' => [
-                  [
-                    {}
-                  ]
-                ]
+                'input_perl_encoding' => 'utf-8'
               },
               'line_nr' => {
                 'file_name' => '',
@@ -170,11 +152,7 @@ $result_trees{'image_and_punctuation'} = {
               'cmdname' => 'image',
               'contents' => [],
               'extra' => {
-                'brace_command_contents' => [
-                  [
-                    {}
-                  ]
-                ]
+                'input_perl_encoding' => 'utf-8'
               },
               'line_nr' => {
                 'file_name' => '',
@@ -220,11 +198,7 @@ $result_trees{'image_and_punctuation'} = {
               'cmdname' => 'image',
               'contents' => [],
               'extra' => {
-                'brace_command_contents' => [
-                  [
-                    {}
-                  ]
-                ]
+                'input_perl_encoding' => 'utf-8'
               },
               'line_nr' => {
                 'file_name' => '',
@@ -270,11 +244,7 @@ $result_trees{'image_and_punctuation'} = {
               'cmdname' => 'image',
               'contents' => [],
               'extra' => {
-                'brace_command_contents' => [
-                  [
-                    {}
-                  ]
-                ]
+                'input_perl_encoding' => 'utf-8'
               },
               'line_nr' => {
                 'file_name' => '',
@@ -321,11 +291,7 @@ $result_trees{'image_and_punctuation'} = {
               'cmdname' => 'image',
               'contents' => [],
               'extra' => {
-                'brace_command_contents' => [
-                  [
-                    {}
-                  ]
-                ]
+                'input_perl_encoding' => 'utf-8'
               },
               'line_nr' => {
                 'file_name' => '',
@@ -355,7 +321,7 @@ $result_trees{'image_and_punctuation'} = {
           }
         ],
         'normalized' => 'Top',
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -368,16 +334,12 @@ $result_trees{'image_and_punctuation'} = {
   'type' => 'document_root'
 };
 $result_trees{'image_and_punctuation'}{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'};
-$result_trees{'image_and_punctuation'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'image_and_punctuation'}{'contents'}[1];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'args'}[0];
-$result_trees{'image_and_punctuation'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'args'}[0];
-$result_trees{'image_and_punctuation'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'args'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[1];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
-$result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[1];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[1];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1];
@@ -385,7 +347,6 @@ $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[2]{'parent'} =
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[3];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[3]{'contents'}[1]{'args'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[3]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[3]{'contents'}[1];
-$result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[3]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[3];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[3];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1];
@@ -393,7 +354,6 @@ $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[4]{'parent'} =
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[5]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[5];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[5]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[5]{'contents'}[1]{'args'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[5]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[5]{'contents'}[1];
-$result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[5]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[5]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[5]{'contents'}[1]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[5];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[5]{'contents'}[2]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[5];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1];
@@ -401,7 +361,6 @@ $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[6]{'parent'} =
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[7]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[7];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[7]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[7]{'contents'}[1]{'args'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[7]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[7]{'contents'}[1];
-$result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[7]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[7]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[7]{'contents'}[1]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[7];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[7]{'contents'}[2]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[7];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[7]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1];
@@ -409,7 +368,6 @@ $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[8]{'parent'} =
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[9]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[9];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[9]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[9]{'contents'}[1]{'args'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[9]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[9]{'contents'}[1];
-$result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[9]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[9]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[9]{'contents'}[1]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[9];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[9]{'contents'}[2]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[9];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[9]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1];
@@ -417,13 +375,11 @@ $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[10]{'parent'}
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11]{'contents'}[1];
-$result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'contents'}[11]{'parent'} = $result_trees{'image_and_punctuation'}{'contents'}[1];
-$result_trees{'image_and_punctuation'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'image_and_punctuation'}{'contents'}[1]{'args'}[0]{'contents'}[1];
+$result_trees{'image_and_punctuation'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'image_and_punctuation'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'extra'}{'node_content'};
-$result_trees{'image_and_punctuation'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'image_and_punctuation'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_and_punctuation'}{'contents'}[1]{'parent'} = $result_trees{'image_and_punctuation'};
 
 $result_texis{'image_and_punctuation'} = '@node Top
@@ -465,26 +421,16 @@ $result_sectioning{'image_and_punctuation'} = {};
 $result_nodes{'image_and_punctuation'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
-$result_nodes{'image_and_punctuation'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'image_and_punctuation'};
 
 $result_menus{'image_and_punctuation'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
@@ -514,6 +460,11 @@ Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 1;
