@@ -915,23 +915,11 @@ $result_nodes{'equivalent_nodes'} = {
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'equivalent_nodes'}{'menu_child'}{'node_prev'} = $result_nodes{'equivalent_nodes'};
 $result_nodes{'equivalent_nodes'}{'menu_child'}{'node_up'} = $result_nodes{'equivalent_nodes'};
 $result_nodes{'equivalent_nodes'}{'node_next'} = $result_nodes{'equivalent_nodes'}{'menu_child'};
-$result_nodes{'equivalent_nodes'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'equivalent_nodes'};
 
 $result_menus{'equivalent_nodes'} = {
   'cmdname' => 'node',
