@@ -17,27 +17,17 @@ $result_trees{'nodes_after_top_before_section_nodes'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'Top'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'node',
@@ -183,34 +173,23 @@ $result_trees{'nodes_after_top_before_section_nodes'} = [
                 'args' => [
                   {
                     'contents' => [
-                      {
-                        'extra' => {
-                          'command' => {}
-                        },
-                        'parent' => {},
-                        'text' => ' ',
-                        'type' => 'empty_spaces_after_command'
-                      },
                       {
                         'parent' => {},
                         'text' => 'menu'
-                      },
-                      {
-                        'parent' => {},
-                        'text' => '
-',
-                        'type' => 'spaces_at_end'
                       }
                     ],
+                    'extra' => {
+                      'spaces_after_argument' => '
+'
+                    },
                     'parent' => {},
-                    'type' => 'misc_line_arg'
+                    'type' => 'line_arg'
                   }
                 ],
                 'cmdname' => 'end',
                 'extra' => {
-                  'command' => {},
                   'command_argument' => 'menu',
-                  'spaces_after_command' => {},
+                  'spaces_before_argument' => ' ',
                   'text_arg' => 'menu'
                 },
                 'line_nr' => {
@@ -222,8 +201,7 @@ $result_trees{'nodes_after_top_before_section_nodes'} = [
               }
             ],
             'extra' => {
-              'end_command' => {},
-              'spaces_after_command' => {}
+              'end_command' => {}
             },
             'line_nr' => {
               'file_name' => '',
@@ -250,7 +228,7 @@ $result_trees{'nodes_after_top_before_section_nodes'} = [
             }
           ],
           'normalized' => 'Top',
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'line_nr' => {
           'file_name' => '',
@@ -272,36 +250,26 @@ $result_trees{'nodes_after_top_before_section_nodes'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'second node'
               }
             ],
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           },
           {
             'contents' => [
-              {
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_before_argument'
-              },
               {
                 'parent' => {},
                 'text' => 'third node'
               }
             ],
+            'extra' => {
+              'spaces_before_argument' => ' '
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           },
           {
             'contents' => [
@@ -311,23 +279,21 @@ $result_trees{'nodes_after_top_before_section_nodes'} = [
               }
             ],
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           },
           {
             'contents' => [
               {
                 'parent' => {},
                 'text' => 'Top'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'node',
@@ -385,7 +351,7 @@ $result_trees{'nodes_after_top_before_section_nodes'} = [
             }
           ],
           'normalized' => 'second-node',
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'line_nr' => {
           'file_name' => '',
@@ -408,26 +374,18 @@ $result_trees{'nodes_after_top_before_section_nodes'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'third node'
               }
             ],
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           },
           {
             'contents' => [],
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           },
           {
             'contents' => [
@@ -437,23 +395,21 @@ $result_trees{'nodes_after_top_before_section_nodes'} = [
               }
             ],
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           },
           {
             'contents' => [
               {
                 'parent' => {},
                 'text' => 'Top'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'node',
@@ -482,7 +438,7 @@ $result_trees{'nodes_after_top_before_section_nodes'} = [
             }
           ],
           'normalized' => 'third-node',
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'line_nr' => {
           'file_name' => '',
@@ -495,36 +451,23 @@ $result_trees{'nodes_after_top_before_section_nodes'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'subsection'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'subsection',
         'contents' => [],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 3,
         'line_nr' => {
@@ -546,10 +489,7 @@ $result_trees{'nodes_after_top_before_section_nodes'} = [
   }
 ];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1];
@@ -575,73 +515,52 @@ $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'content
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'menu_entry_description'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1];
-$result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3];
-$result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3]{'extra'}{'command'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1];
-$result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[3];
-$result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1];
-$result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1];
+$result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'extra'}{'node_content'};
-$result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'element_command'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1];
 $result_trees{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'node'} = $result_trees{'nodes_after_top_before_section_nodes'}[0]{'contents'}[1];
-$result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[1];
-$result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[1];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[2];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[3];
-$result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[3];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'contents'}[1];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1];
+$result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'extra'}{'node_content'};
-$result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'extra'}{'nodes_manuals'}[1]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[1]{'contents'}[1];
+$result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'extra'}{'nodes_manuals'}[1]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[2]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[3]{'contents'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[1];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'element_prev'} = $result_trees{'nodes_after_top_before_section_nodes'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'extra'}{'element_command'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[1]{'extra'}{'node'} = $result_trees{'nodes_after_top_before_section_nodes'}[1]{'contents'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[2];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[3];
-$result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[3]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[3];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[0]{'contents'}[1];
+$result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'extra'}{'node_content'};
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[2]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[3]{'contents'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2];
-$result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1]{'args'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1]{'args'}[0];
-$result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1]{'args'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1];
-$result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1]{'extra'}{'misc_content'}[0] = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section_nodes'}[2];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'element_prev'} = $result_trees{'nodes_after_top_before_section_nodes'}[1];
 $result_trees{'nodes_after_top_before_section_nodes'}[2]{'extra'}{'element_command'} = $result_trees{'nodes_after_top_before_section_nodes'}[2]{'contents'}[0];
@@ -684,9 +603,11 @@ $result_sectioning{'nodes_after_top_before_section_nodes'} = {
         'associated_node' => {
           'cmdname' => 'node',
           'extra' => {
-            'normalized' => 'third-node'
+            'normalized' => 'third-node',
+            'spaces_before_argument' => ' '
           }
-        }
+        },
+        'spaces_before_argument' => ' '
       },
       'level' => 3,
       'number' => 1,
@@ -699,23 +620,28 @@ $result_sectioning{'nodes_after_top_before_section_nodes'}{'section_childs'}[0]{
 $result_nodes{'nodes_after_top_before_section_nodes'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   },
   'menu_child' => {
     'cmdname' => 'node',
     'extra' => {
-      'normalized' => 'second-node'
+      'normalized' => 'second-node',
+      'spaces_before_argument' => ' '
     },
     'node_next' => {
       'cmdname' => 'node',
       'extra' => {
         'associated_section' => {
           'cmdname' => 'subsection',
-          'extra' => {},
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
           'level' => 3,
           'number' => 1
         },
-        'normalized' => 'third-node'
+        'normalized' => 'third-node',
+        'spaces_before_argument' => ' '
       },
       'node_prev' => {},
       'node_up' => {}
@@ -730,49 +656,39 @@ $result_nodes{'nodes_after_top_before_section_nodes'} = {
         'end_command' => {
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'menu',
+            'spaces_before_argument' => ' ',
             'text_arg' => 'menu'
           }
         }
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'nodes_after_top_before_section_nodes'}{'menu_child'}{'node_next'}{'node_prev'} = $result_nodes{'nodes_after_top_before_section_nodes'}{'menu_child'};
 $result_nodes{'nodes_after_top_before_section_nodes'}{'menu_child'}{'node_next'}{'node_up'} = $result_nodes{'nodes_after_top_before_section_nodes'};
 $result_nodes{'nodes_after_top_before_section_nodes'}{'menu_child'}{'node_prev'} = $result_nodes{'nodes_after_top_before_section_nodes'};
 $result_nodes{'nodes_after_top_before_section_nodes'}{'menu_child'}{'node_up'} = $result_nodes{'nodes_after_top_before_section_nodes'};
-$result_nodes{'nodes_after_top_before_section_nodes'}{'menus'}[0]{'extra'}{'end_command'}{'extra'}{'command'} = $result_nodes{'nodes_after_top_before_section_nodes'}{'menus'}[0];
 $result_nodes{'nodes_after_top_before_section_nodes'}{'node_next'} = $result_nodes{'nodes_after_top_before_section_nodes'}{'menu_child'};
-$result_nodes{'nodes_after_top_before_section_nodes'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'nodes_after_top_before_section_nodes'};
 
 $result_menus{'nodes_after_top_before_section_nodes'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   },
   'menu_child' => {
     'cmdname' => 'node',
     'extra' => {
-      'normalized' => 'second-node'
+      'normalized' => 'second-node',
+      'spaces_before_argument' => ' '
     },
     'menu_next' => {
       'cmdname' => 'node',
       'extra' => {
-        'normalized' => 'third-node'
+        'normalized' => 'third-node',
+        'spaces_before_argument' => ' '
       },
       'menu_prev' => {},
       'menu_up' => {},
@@ -814,18 +730,21 @@ $result_elements{'nodes_after_top_before_section_nodes'} = [
                   'element_command' => {
                     'cmdname' => 'node',
                     'extra' => {
-                      'normalized' => 'third-node'
+                      'normalized' => 'third-node',
+                      'spaces_before_argument' => ' '
                     },
                     'menu_prev' => {
                       'cmdname' => 'node',
                       'extra' => {
-                        'normalized' => 'second-node'
+                        'normalized' => 'second-node',
+                        'spaces_before_argument' => ' '
                       },
                       'menu_next' => {},
                       'menu_up' => {
                         'cmdname' => 'node',
                         'extra' => {
-                          'normalized' => 'Top'
+                          'normalized' => 'Top',
+                          'spaces_before_argument' => ' '
                         },
                         'menu_child' => {}
                       },
@@ -841,7 +760,9 @@ $result_elements{'nodes_after_top_before_section_nodes'} = [
                   'node' => {},
                   'section' => {
                     'cmdname' => 'subsection',
-                    'extra' => {},
+                    'extra' => {
+                      'spaces_before_argument' => ' '
+                    },
                     'level' => 3,
                     'number' => 1
                   }
@@ -862,17 +783,6 @@ $result_elements{'nodes_after_top_before_section_nodes'} = [
         },
         'NodeForward' => {},
         'NodeNext' => {},
-        'NodeUp' => {
-          'extra' => {
-            'manual_content' => [
-              {
-                'text' => 'dir'
-              }
-            ],
-            'top_node_up' => {}
-          },
-          'type' => 'external_node'
-        },
         'This' => {}
       },
       'element_command' => {},
@@ -903,7 +813,6 @@ $result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'directions
 $result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'directions'}{'Forward'}{'extra'}{'node'} = $result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'directions'}{'Forward'}{'extra'}{'directions'}{'Forward'}{'extra'}{'element_command'}{'menu_prev'};
 $result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'directions'}{'NodeForward'} = $result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'directions'}{'Forward'};
 $result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'directions'}{'NodeNext'} = $result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'directions'}{'Forward'};
-$result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'directions'}{'NodeUp'}{'extra'}{'top_node_up'} = $result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'directions'}{'Forward'}{'extra'}{'directions'}{'Forward'}{'extra'}{'element_command'}{'menu_prev'}{'menu_up'};
 $result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'directions'}{'This'} = $result_elements{'nodes_after_top_before_section_nodes'}[0];
 $result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'element_command'} = $result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'directions'}{'Forward'}{'extra'}{'directions'}{'Forward'}{'extra'}{'element_command'}{'menu_prev'}{'menu_up'};
 $result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'node'} = $result_elements{'nodes_after_top_before_section_nodes'}[0]{'extra'}{'directions'}{'Forward'}{'extra'}{'directions'}{'Forward'}{'extra'}{'element_command'}{'menu_prev'}{'menu_up'};
@@ -916,7 +825,6 @@ $result_directions_text{'nodes_after_top_before_section_nodes'} = 'element: @nod
   Forward: @node second node
   NodeForward: @node second node
   NodeNext: @node second node
-  NodeUp: (dir)
   This: @node Top
 element: @node second node
   Back: @node Top
@@ -967,6 +875,11 @@ Node: second node131
 Node: third node215
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 
@@ -974,35 +887,26 @@ $result_converted{'html'}->{'nodes_after_top_before_section_nodes'} = '<!DOCTYPE
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
+<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
 <title>Untitled Document</title>
 
 <meta name="description" content="Untitled Document">
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
-<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
 <link href="#Top" rel="start" title="Top">
 <style type="text/css">
 <!--
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
-blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
-blockquote.smallquotation {font-size: smaller}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
 div.lisp {margin-left: 3.2em}
-div.smalldisplay {margin-left: 3.2em}
-div.smallexample {margin-left: 3.2em}
-div.smalllisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
 pre.menu-comment {font-family: serif}
 pre.menu-preformatted {font-family: serif}
-pre.smalldisplay {font-family: inherit; font-size: smaller}
-pre.smallexample {font-size: smaller}
-pre.smallformat {font-family: inherit; font-size: smaller}
-pre.smalllisp {font-size: smaller}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
@@ -1014,23 +918,21 @@ ul.no-bullet {list-style: none}
 </head>
 
 <body lang="en">
-<a name="Top"></a>
-<div class="header">
+<span id="Top"></span><div class="header">
 <p>
-Next: <a href="#second-node" accesskey="n" rel="next">second node</a>, Up: <a href="dir.html#Top" accesskey="u" rel="up">(dir)</a> &nbsp; </p>
+Next: <a href="#second-node" accesskey="n" rel="next">second node</a> &nbsp; </p>
 </div>
 <h1 class="node-heading">Top</h1>
 <p>Top node
 </p><table class="menu" border="0" cellspacing="0">
-<tr><td align="left" valign="top">&bull; <a href="#second-node" accesskey="1">second node</a>:</td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
+<tr><td align="left" valign="top">&bull; <a href="#second-node" accesskey="1">second node</a></td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
 </td></tr>
-<tr><td align="left" valign="top">&bull; <a href="#third-node" accesskey="2">third node</a>:</td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
+<tr><td align="left" valign="top">&bull; <a href="#third-node" accesskey="2">third node</a></td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
 </td></tr>
 </table>
 
 <hr>
-<a name="second-node"></a>
-<div class="header">
+<span id="second-node"></span><div class="header">
 <p>
 Next: <a href="#third-node" accesskey="n" rel="next">third node</a>, Previous: <a href="#Top" accesskey="p" rel="prev">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
 </div>
@@ -1039,13 +941,11 @@ Next: <a href="#third-node" accesskey="n" rel="next">third node</a>, Previous: <
 <p>second node
 </p>
 <hr>
-<a name="third-node"></a>
-<div class="header">
+<span id="third-node"></span><div class="header">
 <p>
 Previous: <a href="#second-node" accesskey="p" rel="prev">second node</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
 </div>
-<a name="subsection"></a>
-<h4 class="subsection">1 subsection</h4>
+<span id="subsection"></span><h4 class="subsection">1 subsection</h4>
 <hr>
 
 
